==> gatsby-theme-code-notes-1.8.0.tgz: package/src/gatsby-plugin-theme-ui/colors.js <==
export const baseColors = {
  grayDark: '#2d3748',
  white: '#fff',
  light: '#f7fafc',
  dark: '#2d3748',
}

export const colors = {
  ...baseColors,
  text: baseColors.dark,
  background: 'hsl(210, 38%, 95%)',
  scrollbar: 'hsl(210, 20%, 85%)',
  backgroundTransparent: 'hsla(210, 38%, 95%, 0.72)',
  contentBg: baseColors.light,
  primary: 'hsl(334, 86%, 48%)',
  primarySemiTransparent: 'hsla(334, 86%, 48%, 0.5)',
  secondary: '#718096',
  muted: '#e2e8f0',
  success: '#9ae6b4',
  info: '#63b3ed',
  warning: '#faf089',
  danger: '#feb2b2',
  navHover: '#cbd5e0',
  codeBackground: '#fbf2e9',
  badgeBg: 'hsl(210, 25%, 97%)',
  badgeBgHover: 'hsl(210, 25%, 89%)',
  badgeBorder: 'hsl(207, 24%, 83%)',
  input: '#92A2B9',
  code1: 'hsl(211, 61%, 23%)',
  code2: '#fc9867',
  code3: '#e3116c',
  code4: '#d73a49',
  code5: 'hsl(211, 61%, 43%)',
  code6: '#6f42c1',
  code7: '#999988',

  modes: {
    dark: {
      text: 'hsl(210, 38%, 95%)',
      background: 'hsl(285, 5%, 17%)',
      scrollbar: 'hsl(285, 5%, 12%)',
      backgroundTransparent: 'hsla(285, 5%, 17%, 0.72)',
      contentBg: '#383539',
      primary: 'hsl(345, 100%, 69%)',
      primarySemiTransparent: 'hsl(345, 100%, 79%, 0.5)',
      secondary: '#718096',
      muted: 'hsl(210, 5%, 40%)',
      success: '#9ae6b4',
      info: '#63b3ed',
      warning: '#faf089',
      danger: '#feb2b2',
      navHover: 'hsl(285, 5%, 13%)',
      codeBackground: '#2d2a2e',
      badgeBg: 'hsl(285, 5%, 17%)',
      badgeBgHover: 'hsl(285, 5%, 20%)',
      badgeBorder: 'hsl(285, 5%, 12%)',
      input: '#ddd',
      code1: 'hsl(345, 100%, 69%)',
      code2: '#fc9867',
      code3: '#ffd866',
      code4: '#a9dc76',
      code5: '#78dce8',
      code6: '#ab9df2',
      code7: '#999988',
    },
  },
}

==> gatsby-theme-code-notes-1.12.0.tgz: package/src/gatsby-plugin-theme-ui/colors.js <==
export const baseColors = {
  grayDark: '#2d3748',
  white: '#fff',
  light: '#f7fafc',
  dark: '#2d3748',
}

export const colors = {
  ...baseColors,
  text: baseColors.dark,
  background: 'hsl(210, 38%, 95%)',
  scrollbar: 'hsl(210, 20%, 85%)',
  backgroundTransparent: 'hsla(210, 38%, 95%, 0.72)',
  contentBg: baseColors.light,
  primary: 'hsl(334, 86%, 48%)',
  primarySemiTransparent: 'hsla(334, 86%, 48%, 0.5)',
  secondary: '#718096',
  muted: '#e2e8f0',
  success: '#9ae6b4',
  info: '#63b3ed',
  warning: '#faf089',
  danger: '#feb2b2',
  navHover: '#cbd5e0',
  codeBackground: 'hsl(210,38%,95%)',
  codeHighlight: 'hsl(210,38%,90%)',
  codeHighlightBorder: 'hsl(210,38%,85%)',
  badgeBg: 'hsl(210, 25%, 97%)',
  badgeBgHover: 'hsl(210, 25%, 89%)',
  badgeBorder: 'hsl(207, 24%, 83%)',
  input: '#92A2B9',
  code1: '#d03592',
  code2: '#fc9867',
  code3: '#f66a0a',
  code4: '#0366d6',
  code5: '#6f42c1',
  code6: '#0366d6',
  code7: '#999988',

  modes: {
    dark: {
      text: 'hsl(210, 38%, 95%)',
      background: 'hsl(285, 5%, 17%)',
      scrollbar: 'hsl(285, 5%, 12%)',
      backgroundTransparent: 'hsla(285, 5%, 17%, 0.72)',
      contentBg: '#383539',
      primary: 'hsl(345, 100%, 69%)',
      primarySemiTransparent: 'hsl(345, 100%, 79%, 0.5)',
      secondary: '#718096',
      muted: 'hsl(210, 5%, 40%)',
      success: '#9ae6b4',
      info: '#63b3ed',
      warning: '#faf089',
      danger: '#feb2b2',
      navHover: 'hsl(285, 5%, 13%)',
      codeBackground: 'hsl(285,5%,17%)',
      codeHighlight: 'hsl(285,5%,25%)',
      codeHighlightBorder: 'hsl(285,5%,20%)',
      badgeBg: 'hsl(285, 5%, 17%)',
      badgeBgHover: 'hsl(285, 5%, 20%)',
      badgeBorder: 'hsl(285, 5%, 12%)',
      input: '#ddd',
      code1: 'hsl(345, 100%, 69%)',
      code2: '#fc9867',
      code3: '#ffd866',
      code4: '#a9dc76',
      code5: '#78dce8',
      code6: '#ab9df2',
      code7: '#999988',
    },
  },
}
